{% extends 'base.html' %}
{% block head %}
<link rel="stylesheet" href="../css/plagiarism-checking-results.css" />
{% endblock %}
{% block content %}
<div class="header">
    <a class="grading-configuration-container" href="plagiarism-configuration1.html">
        <img src="../images/header-bg-long.png" />
        <div class="grading-configuration-text">
            <p>plagiarism</p>
            <p>Configuration</p>
        </div>
    </a>

</div>

<div class="container">
    <div class="main-container">
        <table>
            <tr>
                <th>Homework 1 Name</th>
                <th>Homework 2 Name</th>
                <th>Similarity Score</th>
            </tr>
        </table>
        <div class="table-scroll">
            <table class="table-content">

            </table>

        </div>
    </div>
</div>

<div class="footer">

    <a class="grading-container" href="#">
        <img src="../images/create_assignment_bg_export.png" />
        <p>Export</p>
    </a>
</div>


<script>
    var array = [
        { name1: "Richard", name2: "Stas", score: 100 },
        { name1: "Faizer", name2: "Daniel", score: 50 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
        { name1: "Filler", name2: "Filler", score: 70 },
    ];

    let table = document.querySelector(".table-content");
    let tableData = "";

    array.forEach((data) => {
        tableData += `<tr>
                    <td>${data.name1} </td>
                    <td>${data.name2} </td>
                    <td>${data.score}%</td>
                </tr>
                `
    })

    table.innerHTML = tableData;

    document.getElementById("homework-text").innerHTML = "Homework File: " + sessionStorage.getItem("homework-baseFile");

</script>
{% endblock %}